.. _spkg_sphinx_inline_tabs:

sphinx_inline_tabs: Add inline tabbed content to your Sphinx documentation
====================================================================================

Description
-----------

Add inline tabbed content to your Sphinx documentation

License
-------

Upstream Contact
----------------

https://pypi.org/project/sphinx-inline-tabs/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_sphinx`

Version Information
-------------------

package-version.txt::

    2023.4.21

version_requirements.txt::

    sphinx-inline-tabs


Equivalent System Packages
--------------------------

(none known)

